Regularizers
============

.. automodule:: mumott.optimization.regularizers

.. index::
   single: Class reference; Laplacian 
.. autoclass:: mumott.optimization.regularizers.Laplacian
   :members:
   :undoc-members:
   :inherited-members:
